@@ -2,24 +2,25 @@ package MooX::InsideOut;
 use strict;
 use warnings;
 
-our $VERSION = '0.001003';
-$VERSION = eval $VERSION;
+our $VERSION = '0.001004';
+$VERSION =~ tr/_//d;
 
 use Moo ();
 use Moo::Role ();
 use Carp ();
 
 sub import {
-    my $class = shift;
-    my $target = caller;
+  my $class = shift;
+  my $target = caller;
 
-    my $con = Moo->_constructor_maker_for($target)
-      or Carp::croak "MooX::InsideOut can only be used on Moo classes.";
+  my $con = Moo->_constructor_maker_for($target)
+    or Carp::croak "MooX::InsideOut can only be used on Moo classes.";
 
-    Moo::Role->apply_roles_to_object(
-      Moo->_accessor_maker_for($target),
-      'MooX::InsideOut::Role::GenerateAccessor',
-    );
+  my $ag = Moo->_accessor_maker_for($target);
+  my $role = 'MooX::InsideOut::Role::GenerateAccessor';
+
+  Moo::Role->apply_roles_to_object($ag, $role)
+    unless $ag->does($role);
 }
 
 1;
@@ -32,9 +33,9 @@ MooX::InsideOut - Inside out objects for Moo
 
 =head1 SYNOPSIS
 
-    package MyClass;
-    use Moo;
-    use MooX::InsideOut;
+  package MyClass;
+  use Moo;
+  use MooX::InsideOut;
 
 =head1 DESCRIPTION
 
